==> haskell-retry-0.7.4-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: retry
version: 0.7.4
id: retry-0.7.4-4KkIln1wnXO96818pvgaM8
key: retry-0.7.4-4KkIln1wnXO96818pvgaM8
license: BSD3
copyright: Ozgun Ataman, Soostone Inc
maintainer: ozgun.ataman@soostone.com
homepage: http://github.com/Soostone/retry
synopsis: Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.
category: Control
author: Ozgun Ataman
exposed: True
exposed-modules:
    Control.Retry
abi: 41845ed8221ba07f5bd2c036f7f69c3a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/retry-0.7.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/retry-0.7.4
data-dir: /usr/share/arm-linux-ghc-8.0.1/retry-0.7.4
hs-libraries: HSretry-0.7.4-4KkIln1wnXO96818pvgaM8
depends:
    base-4.9.0.0 data-default-class-0.1.0-En3KOFJqVML6UJ9gz15quU
    exceptions-0.8.2.1-BH4VJoBlnhODiEIhn43wEf ghc-prim-0.5.0.0
    random-1.1-54KmMHXjttlERYcr1mvsAe transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html: /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-retry-0.7.4.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: retry
version: 0.7.4.1
id: retry-0.7.4.1-6HhvnoRQar0Kx9fr2CE8WN
key: retry-0.7.4.1-6HhvnoRQar0Kx9fr2CE8WN
license: BSD3
copyright: Ozgun Ataman, Soostone Inc
maintainer: ozgun.ataman@soostone.com
homepage: http://github.com/Soostone/retry
synopsis: Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.
category: Control
author: Ozgun Ataman
exposed: True
exposed-modules:
    Control.Retry
abi: 0ad0feaad0b2f689428985ecb2079f4e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/retry-0.7.4.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/retry-0.7.4.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/retry-0.7.4.1
hs-libraries: HSretry-0.7.4.1-6HhvnoRQar0Kx9fr2CE8WN
depends:
    base-4.9.0.0 data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    exceptions-0.8.2.1-BH4VJoBlnhODiEIhn43wEf ghc-prim-0.5.0.0
    random-1.1-54KmMHXjttlERYcr1mvsAe transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html: /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
